@@ -10,8 +10,8 @@ from jinja2 import Environment, FileSystemLoader
 here = os.path.dirname(os.path.abspath(__file__))
 
 # Allow includes from this directory OR providing strings
-template_dir = os.path.join(here, "templates")
-env = Environment(loader=FileSystemLoader(template_dir))
+shared_templates_dir = os.path.join(here, "templates")
+env = Environment(loader=FileSystemLoader(shared_templates_dir))
 
 
 class Template:
@@ -19,21 +19,27 @@ class Template:
     Supporting functions for loading any kind of apps template
     """
 
-    def get(self, template_name):
+    def get(self, template_name, template_dir=None):
         """
         Get a template from templates
         """
         template_file = os.path.join(here, "templates", template_name)
+        if template_dir and not os.path.exists(template_file):
+            template_file = os.path.join(template_dir, template_name)
         if not os.path.exists(template_file):
             template_file = os.path.abspath(template_name)
         return template_file
 
-    def load(self, template_name):
+    def load(self, template_name, template_dir=None):
         """
         Load the default module template.
         """
-        template_file = self.get(template_name)
-
+        template_file = self.get(template_name, template_dir)
         with open(template_file, "r") as temp:
+            # If we are given an app template directory, respect it and add to loader
+            if template_dir:
+                env = Environment(
+                    loader=FileSystemLoader([shared_templates_dir, template_dir])
+                )
             template = env.from_string(temp.read())
         return template
